package com.doc.web.controller.system;

import com.doc.biz.service.IDocSpaceService;
import com.doc.chat.domain.ChatMsg;
import com.doc.chat.service.IChatMsgService;
import com.doc.common.constant.Constants;
import com.doc.common.core.domain.AjaxResult;
import com.doc.common.core.domain.entity.SysMenu;
import com.doc.common.core.domain.entity.SysUser;
import com.doc.common.core.domain.model.LoginBody;
import com.doc.common.utils.SecurityUtils;
import com.doc.framework.web.service.SysLoginService;
import com.doc.framework.web.service.SysPermissionService;
import com.doc.system.service.ISysMenuService;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.Set;

/**
 * 登录验证
 *
 * @author ruoyi
 */
@RestController
public class SysLoginController {
    @Resource
    private SysLoginService loginService;

    @Resource
    private ISysMenuService menuService;

    @Resource
    private SysPermissionService permissionService;
    @Resource
    private IDocSpaceService docSpaceService;

    @Resource
    private IChatMsgService msgService;
    @Resource
    private StringRedisTemplate stringRedisTemplate;

    /**
     * 登录方法
     *
     * @param loginBody 登录信息
     * @return 结果
     */
    @PostMapping("/login")
    public AjaxResult login(@RequestBody LoginBody loginBody) {
        AjaxResult ajax = AjaxResult.success();
        // 生成令牌
        String token = loginService.login(loginBody.getUsername(), loginBody.getPassword(), loginBody.getCode(),
                loginBody.getUuid());
        ajax.put(Constants.TOKEN, token);
        return ajax;
    }

    /**
     * 获取用户信息
     *
     * @return 用户信息
     */
    @GetMapping("getInfo")
    public AjaxResult getInfo() {
        SysUser user = SecurityUtils.getLoginUser().getUser();
        // 角色集合
        Set<String> roles = permissionService.getRolePermission(user);
        // 权限集合
        Set<String> permissions = permissionService.getMenuPermission(user);
        AjaxResult ajax = AjaxResult.success();
        ajax.put("user", user);
        ajax.put("roles", roles);
        ajax.put("permissions", permissions);
        ajax.put("repass", loginService.isRepass(user.getUserId()));
        //做个冗余，登录获取用户信息时初始化空间
        docSpaceService.initUserSpace(user);

        //查询用户是否没有聊天记录，如果没有则发送欢迎消息
        List<ChatMsg> list = msgService.selectFriendList(SecurityUtils.getUserId());
        if (list.size() == 0) {
            List<String> contents = new ArrayList<>();
            String content = "实时协作：团队成员可以同时编辑和修改同一文档，实时查看和讨论修改内容，从而节省沟通时间、减少信息衰减、提高协作效率。";
            content += "<br/><br/><br/>版本控制：提供完善的版本控制功，记录文档每次修改并生成新版本号，方便用户追溯修改过程，确保文档可追溯性和可审计性。";
            content += "<br/><br/><br/>全文检索：提供高效而强大的全文检索功能，使您能够根据关键字快速、轻松地查找并定位所需的文件内容。";
            content += "<br/><br/><br/>便捷分享：完工率分享文档，邀请团队成员协作，共同编辑修改，促进团队协作和知识共享，提高团队能力和创造力。";
            content += "<br/><br/><br/>即时通信：即时通信支持一对一消息收发和实时在线交流，保障私密性，并可融合第三方短信系统以扩展通讯方式。";
            content += "<br/><br/><br/>文件内容提取：自动判断文件格式，并对PDF文件内容自动提取、图片文字OCR提取、EXCEL、WORD内容解析以及其他文档类文件内容读取、存储、检索。";
            content += "<br/><br/><br/>一键扫描：通过内部扫描仪设备，执行文档扫描操作，并自动将扫描文件上传至文档中心，扫描文档无需在本地进行存储或拷贝等操作。";
            contents.add(content);
            contents.add("尊敬的用户，欢迎使用聚合智慧文档管理系统！本系统为用户提供了高效、安全、便捷的文件管理体验，包括实时消息发送和接收、文件上传和下载、分享、编辑、预览及协作编辑等功能。");

            contents.forEach(s -> {
                ChatMsg msg = new ChatMsg();
                msg.setMsgType("2");
                msg.setToId(user.getUserId());
                msg.setContent(s);
                msgService.sendSysMsg(msg);
            });
        }

        return ajax;
    }

    /**
     * 获取路由信息
     *
     * @return 路由信息
     */
    @GetMapping("getRouters")
    public AjaxResult getRouters() {
        Long userId = SecurityUtils.getUserId();
        List<SysMenu> menus = menuService.selectMenuTreeByUserId(userId);
        return AjaxResult.success(menuService.buildMenus(menus));
    }
}
