package com.doc.biz.controller;

import cn.hutool.http.HttpUtil;
import com.doc.biz.domain.DocInfo;
import com.doc.biz.domain.DocRecent;
import com.doc.biz.service.IDocInfoService;
import com.doc.biz.service.IDocRecentService;
import com.doc.biz.service.IMongoService;
import com.doc.biz.vo.DocumentVO;
import com.doc.common.core.controller.BaseController;
import com.doc.common.core.domain.AjaxResult;
import com.doc.common.utils.SecurityUtils;
import com.doc.system.service.ISysConfigService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.File;
import java.io.IOException;
import java.nio.file.Files;
import java.util.HashMap;

/**
 * 文件上传
 *
 * @author wukai
 * @date 2023-08-15
 */
@Slf4j
@Api(tags = "通用接口")
@RestController
@RequestMapping("/api")
public class ApiController extends BaseController {

    /**
     * 文件上传实现类
     */
    @Resource
    private IMongoService mongoService;
    @Resource
    private ISysConfigService configService;
    @Resource
    private IDocRecentService recentService;
    @Resource
    private IDocInfoService docInfoService;

    /**
     * 文件下载
     *
     * @param docId docId
     * @return
     */
    @ApiOperation("文件预览")
    @GetMapping("/access/{docId}")
    public ResponseEntity<Object> access(@PathVariable(name = "docId") Long docId, @RequestParam Long uid) {
        DocInfo info = docInfoService.selectDocInfoByDocId(docId);
        //插入最近文件
        DocRecent recent = new DocRecent();
        recent.setIsFolder("N");
        recent.setOwner(uid);
        recent.setRelaId(info.getDocId());
        recentService.insertDocRecent(recent);
        return mongoService.download(info.getFileId(), false);
    }

    /**
     * 文字识别
     *
     * @param fileId fileId
     * @return
     */
    @ApiOperation("文字识别-通过fileId")
    @GetMapping("/ocr/{fileId}")
    public AjaxResult ocr(@PathVariable(name = "fileId") String fileId) {
        DocumentVO vo = mongoService.downloadFile(fileId);
        try {
            File upFile = File.createTempFile(vo.getFileName(), vo.getSuffix() + ".");
            Files.write(upFile.toPath(), vo.getData());
            String result = callPythonOcrApi(upFile);
            return success(result);
        } catch (IOException e) {
            return error(e.getMessage());
        }
    }


    /**
     * 文字识别
     *
     * @param file 文件
     * @return
     */
    @ApiOperation("文字识别-上传图片")
    @PostMapping("/upload")
    public AjaxResult ocr(@RequestParam(value = "file") MultipartFile file) {
        try {
            //选择用缓冲区来实现这个转换即使用java 创建的临时文件 使用 MultipartFile.transferto()方法 。
            String originalFilename = file.getOriginalFilename();
            String[] filename = originalFilename.split("\\.");
            File upFile = File.createTempFile(filename[0], filename[1] + ".");
            file.transferTo(upFile);
            String result = callPythonOcrApi(upFile);
            return success(result);
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 调用python接口获取结果
     *
     * @param file 文件
     * @return 识别结果
     */
    private String callPythonOcrApi(File file) {
        HashMap<String, Object> map = new HashMap<>(3);
        map.put("file", file);
        String uri = configService.selectConfigByKey("api.ocr.uri");
        String result = HttpUtil.post(uri, map);
        try {
            Files.delete(file.toPath());
        } catch (IOException e) {
        }
        return result;
    }
}
