package com.doc.biz.controller;

import com.doc.biz.domain.DocDirLevel;
import com.doc.biz.service.IDocDirLevelService;
import com.doc.common.annotation.Log;
import com.doc.common.core.controller.BaseController;
import com.doc.common.core.domain.AjaxResult;
import com.doc.common.core.page.TableDataInfo;
import com.doc.common.enums.BusinessType;
import com.doc.common.enums.EventLevel;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * 目录加密级别管理Controller
 *
 * @author wukai
 * @date 2023-10-19
 */
@Api(tags = "目录加密级别管理")
@RestController
@RequestMapping("/biz/level")
public class DocDirLevelController extends BaseController {
    @Resource
    private IDocDirLevelService docDirLevelService;

    /**
     * 查询目录加密级别管理列表
     */
    @ApiOperation("查询目录加密级别管理列表")
//    @PreAuthorize("@ss.hasPermi('biz:level:list')")
    @GetMapping("/list")
    public TableDataInfo list(DocDirLevel docDirLevel) {
        startPage();
        List<DocDirLevel> list = docDirLevelService.selectDocDirLevelList(docDirLevel);
        return getDataTable(list);
    }

    /**
     * 修改目录加密级别管理
     */
    @ApiOperation("修改目录加密级别管理")
    @PreAuthorize("@ss.hasPermi('biz:level:edit')")
    @Log(title = "目录加密级别管理", businessType = BusinessType.UPDATE, eventLevel = EventLevel.HIGH)
    @PutMapping
    public AjaxResult edit(@RequestBody List<DocDirLevel> docDirLevel) {
        return toAjax(docDirLevelService.updateDocDirLevel(docDirLevel));
    }

    /**
     * 获取目录加密级别管理详细信息
     */
    @ApiOperation("获取目录加密级别管理详细信息")
//    @PreAuthorize("@ss.hasPermi('biz:level:query')")
    @GetMapping(value = "/{levelCode}")
    public AjaxResult getInfo(@PathVariable("levelCode") String levelCode) {
        return success(docDirLevelService.selectDocDirLevelByLevelCode(levelCode));
    }


    /**
     * 导出目录加密级别管理列表
     */
//    @ApiOperation("导出目录加密级别管理列表")
//    @PreAuthorize("@ss.hasPermi('biz:level:export')")
//    @Log(title = "目录加密级别管理", businessType = BusinessType.EXPORT)
//    @PostMapping("/export")
//    public void export(HttpServletResponse response, DocDirLevel docDirLevel) {
//        List<DocDirLevel> list = docDirLevelService.selectDocDirLevelList(docDirLevel);
//        ExcelUtil<DocDirLevel> util = new ExcelUtil<DocDirLevel>(DocDirLevel.class);
//        util.exportExcel(response, list, "目录加密级别管理数据");
//    }


    /**
     * 新增目录加密级别管理
     */
//    @ApiOperation("新增目录加密级别管理")
//    @PreAuthorize("@ss.hasPermi('biz:level:add')")
//    @Log(title = "目录加密级别管理", businessType = BusinessType.INSERT)
//    @PostMapping
//    public AjaxResult add(@RequestBody DocDirLevel docDirLevel) {
//        return toAjax(docDirLevelService.insertDocDirLevel(docDirLevel));
//    }


    /**
     * 删除目录加密级别管理
     */
//    @ApiOperation("删除目录加密级别管理")
//    @PreAuthorize("@ss.hasPermi('biz:level:remove')")
//    @Log(title = "目录加密级别管理", businessType = BusinessType.DELETE)
//    @DeleteMapping("/{levelIds}")
//    public AjaxResult remove(@PathVariable Long[] levelIds) {
//        return toAjax(docDirLevelService.deleteDocDirLevelByLevelIds(levelIds));
//    }
}
