package com.doc.biz.controller;

import com.alibaba.fastjson2.JSONObject;
import com.doc.biz.domain.DocInfo;
import com.doc.biz.domain.DocVersion;
import com.doc.biz.service.IDocInfoService;
import com.doc.biz.service.IDocVersionService;
import com.doc.biz.service.IMongoService;
import com.doc.biz.vo.DocumentVO;
import com.doc.common.core.domain.entity.SysUser;
import com.doc.common.utils.file.FileUtils;
import com.doc.system.service.ISysUserService;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.PrintWriter;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.Date;
import java.util.Scanner;

/**
 * 分组成员Controller
 *
 * @author wukai
 * @date 2023-03-27
 */
@RestController
@RequestMapping("/only-office")
public class OnlyOfficeController {
    @Resource
    private IDocInfoService docInfoService;
    @Resource
    private IMongoService mongoService;
    @Resource
    private IDocVersionService versionService;
    @Resource
    private ISysUserService userService;

    /**
     * only office修改回调
     *
     * @param id       文档ID
     * @param request  请求参数
     * @param response 响应参数
     */
    @RequestMapping("/callback/{id}")
    @ResponseBody
    public void save(@PathVariable("id") Long id, HttpServletRequest request, HttpServletResponse response) throws Exception {
        PrintWriter writer = null;
        String body = "";
        try (Scanner scanner = new Scanner(request.getInputStream());) {
            writer = response.getWriter();
            scanner.useDelimiter("\\A");
            body = scanner.hasNext() ? scanner.next() : "";
        } catch (Exception ex) {
            writer.write("get request.getInputStream error:" + ex.getMessage());
            return;
        }

        if (body.isEmpty()) {
            throw new Exception("ONLYOFFICE回调保存请求体为空");
        }

        JSONObject jsonObj = JSONObject.parseObject(body);
        int status = (Integer) jsonObj.get("status");
       /* 定义文档的状态。 可以有以下值：
        1 - 正在编辑文档，
        2 - 文档已准备好保存，
        3 - 发生文档保存错误，
        4 - 文档已关闭，没有任何更改，
        6 - 正在编辑文档，但保存了当前文档状态，
        7 - 强制保存文档时发生错误。*/
        int save = 2;
        int saveError = 3;
        int forceSave = 6;
        int saved = 0;
        String key = jsonObj.get("key").toString();
        if (status == save || status == saveError || status == forceSave) {
            //获取用户信息
            SysUser user = userService.selectUserById(jsonObj.getJSONArray("actions").getJSONObject(0).getLong("userid"));

            String downloadUri = (String) jsonObj.get("url");
            DocInfo info = docInfoService.selectDocInfoByDocId(id);
            //保存版本信息
            DocVersion version = new DocVersion();
            version.setDocId(id);
            version.setFileId(info.getFileId());
            version.setCreateBy(info.getCreateBy());
            version.setCreateTime(info.getCreateTime());
            versionService.insertDocVersion(version);

            try {
                URL url = new URL(downloadUri);
                HttpURLConnection connection = (java.net.HttpURLConnection) url.openConnection();

                MultipartFile multipartFile = FileUtils.getMultipartFile(connection.getInputStream(), info.getFileName());
                //保存新的文件信息
                DocumentVO vo = mongoService.uploadFile(multipartFile);
                info.setFileId(vo.getFileId());
                info.setFileSize(vo.getFileSize());
                info.setCreateBy(user.getUserName());
                info.setCreateTime(new Date());
                info.setUpdateBy(user.getUserName());
                docInfoService.updateDocInfo(info);

                connection.disconnect();
            } catch (Exception ex) {
                saved = 1;
                ex.printStackTrace();
            }
        }
        writer.write("{\"error\":" + saved + "}");
    }
}
