package com.doc.biz.domain;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.doc.common.annotation.Excel;
import com.doc.common.core.domain.TreeEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;

import java.util.List;

/**
 * 文档目录管理对象 doc_dir
 *
 * @author wukai
 * @date 2023-08-21
 */
@Data
@ApiModel(value = "DocDir", description = "文档目录管理")
public class DocDir extends TreeEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 目录ID
     */
    @ApiModelProperty("目录ID")
    @TableId
    private Long dirId;

    /**
     * 空间ID
     */
    @ApiModelProperty("空间ID")
    private Long spaceId;

    /**
     * 目录类型
     */
    @ApiModelProperty("目录类型 1.普通目录 2.组织目录")
    @Excel(name = "目录类型")
    private String dirType;

    /**
     * 目录权限
     */
    @ApiModelProperty("目录权限")
    @Excel(name = "目录权限")
    private String dirRole;

    /**
     * 目录名称
     */
    @ApiModelProperty("目录名称")
    @Excel(name = "目录名称")
    private String dirName;
    @ApiModelProperty("是否加密")
    private String isEncrypt;
    @ApiModelProperty("加密级别")
    private String encryptLevel;

    /**
     * 目录路径
     */
    @ApiModelProperty("目录路径")
    private String dirPath;

    @ApiModelProperty("是否收藏 Y/N")
    private String isFavorite;

    @ApiModelProperty("目录人员")
    @TableField(exist = false)
    private List<DocDirUser> users;


    @Override
    public String toString() {
        return new ToStringBuilder(this, ToStringStyle.MULTI_LINE_STYLE)
                .append("dirId", getDirId())
                .append("spaceId", getSpaceId())
                .append("dirType", getDirType())
                .append("dirRole", getDirRole())
                .append("dirName", getDirName())
                .append("parentId", getParentId())
                .append("dirPath", getDirPath())
                .append("createBy", getCreateBy())
                .append("createTime", getCreateTime())
                .append("updateBy", getUpdateBy())
                .append("updateTime", getUpdateTime())
                .append("remark", getRemark())
                .toString();
    }
}
