package com.doc.biz.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.doc.biz.domain.DocSpace;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 文档空间管理Mapper接口
 *
 * @author wukai
 * @date 2023-08-15
 */
public interface DocSpaceMapper extends BaseMapper<DocSpace> {
    /**
     * 查询文档空间管理
     *
     * @param spaceId 文档空间管理主键
     * @return 文档空间管理
     */
    public DocSpace selectDocSpaceBySpaceId(Long spaceId);

    /**
     * 查询文档空间管理列表
     *
     * @param docSpace 文档空间管理
     * @return 文档空间管理集合
     */
    public List<DocSpace> selectDocSpaceList(DocSpace docSpace);

    /**
     * 新增文档空间管理
     *
     * @param docSpace 文档空间管理
     * @return 结果
     */
    public int insertDocSpace(DocSpace docSpace);

    /**
     * 修改文档空间管理
     *
     * @param docSpace 文档空间管理
     * @return 结果
     */
    public int updateDocSpace(DocSpace docSpace);

    /**
     * 删除文档空间管理
     *
     * @param spaceId 文档空间管理主键
     * @return 结果
     */
    public int deleteDocSpaceBySpaceId(Long spaceId);

    /**
     * 批量删除文档空间管理
     *
     * @param spaceIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDocSpaceBySpaceIds(Long[] spaceIds);

    /**
     * 根据用户查询出该用户所有空间信息
     *
     * @param userId 用户ID
     * @return 结果
     */
    List<DocSpace> selectDocSpaceByUser(@Param("userId") Long userId);

    /**
     * 根据spaceId更新空间使用情况
     *
     * @param spaceId 空间ID
     * @return i
     */
    int updateUsedCap(Long spaceId);

    /**
     * 增加容量
     *
     * @param spaceId   空间ID
     * @param expandCap 容量大小
     */
    void addCap(@Param("spaceId") Long spaceId, @Param("cap") Long expandCap);
}
