package com.doc.biz.service;

import com.doc.biz.domain.DocDirLevel;

import java.util.List;

/**
 * 文档目录加密级别Service接口
 *
 * @author wukai
 * @date 2023-10-19
 */
public interface IDocDirLevelService {
    /**
     * 查询文档目录加密级别
     *
     * @param levelId 文档目录加密级别主键
     * @return 文档目录加密级别
     */
    public DocDirLevel selectDocDirLevelByLevelId(Long levelId);

    /**
     * 查询文档目录加密级别
     *
     * @param levelCode 文档目录加密级别编码
     * @return 文档目录加密级别
     */
    DocDirLevel selectDocDirLevelByLevelCode(String levelCode);

    /**
     * 查询文档目录加密级别列表
     *
     * @param docDirLevel 文档目录加密级别
     * @return 文档目录加密级别集合
     */
    public List<DocDirLevel> selectDocDirLevelList(DocDirLevel docDirLevel);

    /**
     * 新增文档目录加密级别
     *
     * @param docDirLevel 文档目录加密级别
     * @return 结果
     */
    public int insertDocDirLevel(DocDirLevel docDirLevel);

    /**
     * 修改文档目录加密级别
     *
     * @param docDirLevel 文档目录加密级别
     * @return 结果
     */
    public int updateDocDirLevel(DocDirLevel docDirLevel);

    /**
     * 修改文档目录加密级别
     *
     * @param docDirLevel 文档目录加密级别
     * @return 结果
     */
    public int updateDocDirLevel(List<DocDirLevel> docDirLevel);

    /**
     * 批量删除文档目录加密级别
     *
     * @param levelIds 需要删除的文档目录加密级别主键集合
     * @return 结果
     */
    public int deleteDocDirLevelByLevelIds(Long[] levelIds);

    /**
     * 删除文档目录加密级别信息
     *
     * @param levelId 文档目录加密级别主键
     * @return 结果
     */
    public int deleteDocDirLevelByLevelId(Long levelId);


}
