package com.doc.biz.service;

import com.doc.biz.vo.DocumentVO;
import org.springframework.http.ResponseEntity;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * Mongo存储Service接口
 *
 * @author wukai
 * @date 2023-08-15
 */
public interface IMongoService {
    /**
     * 文件上传
     *
     * @param file 文件
     * @return 结果
     * @throws Exception
     */
    DocumentVO uploadFile(MultipartFile file) throws Exception;

    /**
     * 多文件上传
     *
     * @param files 文件
     * @return 结果
     */
    List<DocumentVO> uploadFiles(List<MultipartFile> files);

    /**
     * 文件下载
     *
     * @param fileId 文件ID
     * @return 结果
     */
    DocumentVO downloadFile(String fileId);

    /**
     * 前端文件下载
     *
     * @param fileId 文件ID
     * @param isDown 是否下载
     * @return 下载流
     */
    ResponseEntity<Object> download(String fileId, boolean isDown);

    /**
     * 文件删除
     *
     * @param fileId 文件ID
     */
    void removeFile(String fileId);

    /**
     * 查询并复制mongo文件
     *
     * @param fileId 文件id
     * @return 结果
     */
    DocumentVO copy(String fileId);
}
