package com.doc.biz.service.impl;

import com.doc.biz.domain.DocInfo;
import com.doc.biz.domain.EsDocInfo;
import com.doc.biz.service.IElasticSearchService;
import com.doc.biz.service.IEsDocInfoService;
import com.doc.biz.service.IMongoService;
import com.doc.biz.vo.DocumentVO;
import com.doc.common.config.EsConfig;
import com.doc.common.utils.FileContentUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;
import java.util.function.Function;

/**
 * ElasticSearch 索引接口
 *
 * @author wukai
 * @date 2023-08-15
 */
@Service
public class ElasticSearchServiceImpl implements IElasticSearchService {
    @Resource
    private IEsDocInfoService esDocInfoService;
    @Resource
    private EsConfig esConfig;
    @Resource
    private IMongoService mongoService;

    /**
     * 文件内容入es库
     *
     * @param info 文档信息
     */
    @Override
    public void save(DocInfo info) {
        if (info.getFileSize() == 0) {
            return;
        }
        Map<String, Function<byte[], String>> handlerMap = new HashMap<>(16);
        handlerMap.put(".docx", FileContentUtils::getContentDocx);
        handlerMap.put(".doc", FileContentUtils::getContentDoc);
        handlerMap.put(".wps", FileContentUtils::getContentWps);
        handlerMap.put(".txt", FileContentUtils::getContentTxt);

        Function<byte[], String> handler = handlerMap.get(info.getFileType());
        if (handler != null) {
            //组装ES索引名
            String indexName = "docs_" + info.getSpaceId();
            //获取文件
            DocumentVO vo = mongoService.downloadFile(info.getFileId());
            if (vo != null) {
                String content = handler.apply(vo.getData());
                EsDocInfo esDocInfo = new EsDocInfo(info.getDocId(), content);

                esConfig.setIndexName(indexName);
                esDocInfoService.save(esDocInfo);
            }
        }
    }

    /**
     * 通过ID删除ES内容
     *
     * @param info 文档信息
     */
    @Override
    public void delete(DocInfo info) {
        //组装ES索引名
        String indexName = "docs_" + info.getSpaceId();

        esConfig.setIndexName(indexName);
        esDocInfoService.deleteById(info.getDocId());
    }
}
