package com.doc.chat.service;

import com.doc.chat.domain.ChatMsg;

import java.util.List;

/**
 * 聊天消息管理;Service接口
 *
 * @author wukai
 * @date 2023-08-24
 */
public interface IChatMsgService {
    /**
     * 查询聊天消息管理;
     *
     * @param msgId 聊天消息管理;主键
     * @return 聊天消息管理;
     */
    public ChatMsg selectChatMsgByMsgId(Long msgId);

    /**
     * 查询聊天消息管理;列表
     *
     * @param chatMsg 聊天消息管理;
     * @return 聊天消息管理;集合
     */
    public List<ChatMsg> selectChatMsgList(ChatMsg chatMsg);

    /**
     * 新增聊天消息管理;
     *
     * @param chatMsg 聊天消息管理;
     * @return 结果
     */
    public int insertChatMsg(ChatMsg chatMsg);

    /**
     * 修改聊天消息管理;
     *
     * @param chatMsg 聊天消息管理;
     * @return 结果
     */
    public int updateChatMsg(ChatMsg chatMsg);

    /**
     * 批量删除聊天消息管理;
     *
     * @param msgIds 需要删除的聊天消息管理;主键集合
     * @return 结果
     */
    public int deleteChatMsgByMsgIds(Long[] msgIds);

    /**
     * 删除聊天消息管理;信息
     *
     * @param msgId 聊天消息管理;主键
     * @return 结果
     */
    public int deleteChatMsgByMsgId(Long msgId);

    /**
     * 获取聊天记录
     *
     * @param fromId 当前用户ID
     * @param toId   接收用户ID
     * @return 聊天记录列表
     */
    List<ChatMsg> selectRecordList(Long fromId, Long toId);

    /**
     * 查询好友列表
     *
     * @param userId 当前用户ID
     * @return
     */
    List<ChatMsg> selectFriendList(Long userId);

    /**
     * 发送消息
     *
     * @param msg 消息对象
     * @return 结果
     */
    int send(ChatMsg msg);

    /**
     * 发送系统消息
     * @param msg 消息
     * @return 结果
     */
    int sendSysMsg(ChatMsg msg);
}
