package com.doc.system.service.impl;

import com.doc.common.core.domain.entity.SysUserExpand;
import com.doc.system.mapper.SysUserExpandMapper;
import com.doc.system.service.ISysUserExpandService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 用户登录限制Service业务层处理
 *
 * @author wukai
 * @date 2023-10-11
 */
@Service
public class SysUserExpandServiceImpl implements ISysUserExpandService {
    @Resource
    private SysUserExpandMapper sysUserExpandMapper;

    /**
     * 查询用户登录限制
     *
     * @param userId 用户登录限制主键
     * @return 用户登录限制
     */
    @Override
    public SysUserExpand selectSysUserExpandByUserId(Long userId) {
        return sysUserExpandMapper.selectSysUserExpandByUserId(userId);
    }

    /**
     * 查询用户登录限制列表
     *
     * @param sysUserExpand 用户登录限制
     * @return 用户登录限制
     */
    @Override
    public List<SysUserExpand> selectSysUserExpandList(SysUserExpand sysUserExpand) {
        return sysUserExpandMapper.selectSysUserExpandList(sysUserExpand);
    }

    /**
     * 新增用户登录限制
     *
     * @param sysUserExpand 用户登录限制
     * @return 结果
     */
    @Override
    public int insertSysUserExpand(SysUserExpand sysUserExpand) {
        return sysUserExpandMapper.insertSysUserExpand(sysUserExpand);
    }

    /**
     * 修改用户登录限制
     *
     * @param sysUserExpand 用户登录限制
     * @return 结果
     */
    @Override
    public int updateSysUserExpand(SysUserExpand sysUserExpand) {
        SysUserExpand u = sysUserExpandMapper.selectSysUserExpandByUserId(sysUserExpand.getUserId());
        /**
         * 查询用户扩展信息是否存在，如果不存在则创建
         */
        if (u != null) {
            return sysUserExpandMapper.updateSysUserExpand(sysUserExpand);
        } else {
            return sysUserExpandMapper.insertSysUserExpand(sysUserExpand);
        }
    }

    /**
     * 批量删除用户登录限制
     *
     * @param userIds 需要删除的用户登录限制主键
     * @return 结果
     */
    @Override
    public int deleteSysUserExpandByUserIds(Long[] userIds) {
        return sysUserExpandMapper.deleteSysUserExpandByUserIds(userIds);
    }

    /**
     * 删除用户登录限制信息
     *
     * @param userId 用户登录限制主键
     * @return 结果
     */
    @Override
    public int deleteSysUserExpandByUserId(Long userId) {
        return sysUserExpandMapper.deleteSysUserExpandByUserId(userId);
    }
}
